@@ -51,10 +51,13 @@ def __run(config, strategy_loader):
         environment.market_api.Init()
 
         environment.basicdata_api = BasicDataApi()
-
+        
         if environment.config.run_type == 'PAPER_TRADING':
             environment.trade_api = PaperTradeApi(event_bus)
             environment.trade_api.Init()
+        if environment.config.run_type == 'YK_PAPER_TRADING':
+            environment.trade_api = YKPaperTradeApi(event_bus)
+            environment.trade_api.Init()
         elif environment.config.run_type == 'LIVE_TRADING':
             environment.trade_api = RealTradeApi(event_bus)
             environment.trade_api.Init()
