@@ -33,16 +33,26 @@ class Environment(object):
             return urljoin("https://dev_apigateway.inquantstudio.com/", relativeUrl)
         return urljoin("https://apigateway.inquantstudio.com/", relativeUrl)
 
+    def get_ykapiurl(self,relativeUrl):
+        if self.config.runtime == 'DEBUG':
+            return urljoin("https://dev_vir.inquant.cn/", relativeUrl)
+        return urljoin("https://vir.inquant.cn/", relativeUrl)
+
     def get_quoteaddr(self):
         if self.config.runtime == 'DEBUG':
             return "wss://dev_quotegateway.inquantstudio.com"
         return "wss://quotegateway.inquantstudio.com"
-
+    
     def get_trademsgaddr(self):
         if self.config.runtime == 'DEBUG':
             return "wss://dev_apigateway.inquantstudio.com/msg/"
         return "wss://apigateway.inquantstudio.com/msg/"
 
+    def get_yktrademsgaddr(self):
+        if self.config.runtime == 'DEBUG':
+            return "wss://dev_vir.inquant.cn/msg/"
+        return "wss://vir.inquant.cn/msg/"
+
     def get_livetradeaddr(self):
         if self.config.runtime == 'DEBUG':
             return "https://dev_trade.inquant.cn/tradeAcc/"
@@ -64,7 +74,7 @@ class GlobalConfig(object):
         """
         self.log = None
 
-        """交易类型 BACKTEST PAPER_TRADING LIVE_TRADING"""
+        """交易类型 BACKTEST PAPER_TRADING LIVE_TRADING  YK_PAPER_TRADING"""
         self.run_type = None
 
         """外部通知配置
@@ -81,6 +91,12 @@ class GlobalConfig(object):
                 "strategy_id":"1021",
                 "account":"2012"
             }
+            pc模拟盘:
+            {
+                "strategy_id":"21",
+                "account":"10034",
+                "user_token":"Ol2OTtExAI29PCeKuEJuKg**"
+            }
             实盘:
             {
                 "strategy_id":"1021",
