@@ -2,7 +2,6 @@
 import numpy as np
 from iqsopenapi import *
 import datetime
-import talib
 
 def on_init(ctx):
     #variables
@@ -14,14 +13,22 @@ def on_init(ctx):
     ctx.domi_contract = None
     ctx.last_domi = None
 
+    risk = ctx.get_risk()
+
+    fixed_hand = risk['fixed_hand']
+
+    risk_ratio = risk['risk_ratio']
+
     positions = ctx.get_positions()
 
     position = ctx.get_position('rb2010.SHFE')
 
-    # order = ctx.insert_order('m2009.DCE',OrderSide.Sell,OrderType.MKT,Offset.Open,0,8)
-    # order = ctx.insert_order('m2009.DCE',OrderSide.Buy,OrderType.MKT,Offset.Open,0,5)
+    # order =
+    # ctx.insert_order('m2009.DCE',OrderSide.Sell,OrderType.MKT,Offset.Open,0,8)
+    # order =
+    # ctx.insert_order('m2009.DCE',OrderSide.Buy,OrderType.MKT,Offset.Open,0,5)
 
-    order = ctx.insert_smart_order('p2009.DCE', -3)
+    order = ctx.insert_smart_order('c2009.DCE', -20)
 
     id = ctx.get_strategy_id()
 
@@ -139,25 +146,29 @@ def on_bar(ctx,bar):
     #    ctx.last_low = bar.low
 config = {
     "runtime":"DEBUG",
-    "run_type":"LIVE_TRADING",
+    "run_type":"PAPER_TRADING",
     "log":{
             'level':'INFO',
-            'file' :r"D:\logs\test\strategy.log",
+            'file' :"/home/admin/logs/strategy.log",
         },
     #"ext_notify":{
     #        "type":"websocket",
     #        "address":"ws://localhost:14002/"
     #    },
-    # "acct_info":{
-    #        "strategy_id":"21",
-    #        "account":"10030"
-    #    }
     "acct_info":{
-            "strategy_id":"1021",
-            "account":"093959",
-            "password":"640423",
-            "comp_counter": 96,
-            "broker_type":152
-        }
+        "strategy_id":"21",
+        "account":"10030"
+    },
+    "risk":{
+        "fixed_hand":10,
+        "risk_ratio":1.0
+    }
+    #"acct_info":{
+    #        "strategy_id":"1021",
+    #        "account":"093959",
+    #        "password":"640423",
+    #        "comp_counter": 96,
+    #        "broker_type":152
+    #    }
 }
 run_func(**globals())
\ No newline at end of file
