@@ -9,58 +9,58 @@ class TickData(object):
     def __init__(self):
 
         """股票代码或合约名称"""
-        self.Symbol = ""
+        self.symbol = ""
 
         """交易所"""
-        self.Exchange = Exchange.UnKnow
+        self.exchange = Exchange.UnKnow
 
         """时间"""
-        self.LocalTime = datetime.now()
+        self.local_time = datetime.now()
 
         """最新成交价"""
-        self.LastPx = 0.0
+        self.last = 0.0
 
         """成交量"""
-        self.Volume = 0
+        self.volume = 0
 
         """持仓量"""
-        self.OpenInterest = 0
+        self.open_interest = 0
 
         """开盘价"""
-        self.OpenPx = 0.0
+        self.open = 0.0
 
         """最高价"""
-        self.HighPx = 0.0
+        self.high = 0.0
 
         """最低价"""
-        self.LowPx = 0.0
+        self.low = 0.0
 
         """总成交额"""
-        self.Amount = 0.0
+        self.turnover = 0.0
 
         """结算价"""
-        self.SettlementPx = 0.0
+        self.settlement = 0.0
 
         """跌停价"""
-        self.DownLimitPx = 0.0
+        self.lower_limit = 0.0
 
         """涨停价"""
-        self.UpLimitPx = 0.0
+        self.upper_limit = 0.0
 
         """昨收"""
-        self.PreClosePx = 0.0
+        self.pre_close = 0.0
 
         """买N档"""
-        self.Bids = []
+        self.bids = []
 
         """卖N档"""
-        self.Asks = []
+        self.asks = []
 
 class LevelUnit(object):
     """一档行情"""
 
     def __init__(self):
         """价格"""
-        self.Px = 0
+        self.price = 0
         """量"""
-        self.Vol = 0
\ No newline at end of file
+        self.volume = 0
\ No newline at end of file
