@@ -143,7 +143,7 @@ def ParseUserAssetsModel(json):
     info.account_id = json['accountID']
     info.total_value = float(json['total'])
     info.available = float(json['available'])
-    info.fozen_cash = float(json['frozenBalance'])
+    info.frozen_cash = float(json['frozenBalance'])
     info.market_value = float(json['marketBalance'])
     info.margin = float(json['margin'])
     info.begin_balance = float(json['beginBalance'])
@@ -193,6 +193,7 @@ def ParsePositionModel(json):
         info.side = PosSide(item['posSide'])
         info.margin = float(item['margin'])
         info.value = float(item['marketValue'])
+        info.profit = float(item['dropIncome'])
         info.today_qty = int(item['todayVol'])
         info.today_avl = int(item['todayEnableVol'])
         model.Positions.append(info)
